'''
This is used to generate a password containing strings and numbers

'''

import random
import string


def password_generator(number_of_characters):
    '''
    Generates a password containing characters and numbers

    parameter(number_of_characters):
    To specify the number of charactes needed to generate the password

    Retruns:
    The password as a string

    '''

    password = ("".join(random.choices(
        string.ascii_letters + string.digits, k=number_of_characters)))
    return password



import setuptools
from pathlib import Path

setuptools.setup(
    name="kbgenerate",
    version=1.0,
    long_description=Path("README.md").read_text(),
    packages=setuptools.find_packages()
    # here we can include excludes to include an array of files or packages to exclude
)
